#  Copyright (c) 2020. Brendan Johnson. All Rights Reserved.

#import connect
#import config

class SystemSettings:
    def __init__(self, config, connection):
        self._config=config
        self._connection = connection
    ##SystemSettings
    def list(self):
        return self._connection.get(url='/systemsettings')
    def modify(self, settingName, payload):
        return self._connection.post(url='/systemsettings/{name}'.format(name=settingName), data=payload)
    def describe(self, settingName):
        return self._connection.get(url='/systemsettings/{name}'.format(name=settingName))
    def modify(self, payload):
        return self._connection.post(url='/systemsettings', data=payload)
    def delete(self, settingName):
        return self._connection.delete(url='/systemsettings/{name}'.format(name=settingName))


#  Copyright (c) 2020. Brendan Johnson. All Rights Reserved.

import logging

class Config():
    def __init__(self):
        """Constructor"""
        # Default Base url
        self.host = "https://dsm.example.com:4119/api"
        self.api_key = {}
        self.username = ""
        self.password = ""

        # Logging Settings
        self.logger = {}
        self.logger["urllib3_logger"] = logging.getLogger("urllib3")
        # Log format
        self.logger_format = '%(asctime)s %(levelname)s %(message)s'
        # Log stream handler
        self.logger_stream_handler = None
        # Log file handler
        self.logger_file_handler = None
        # Debug file location
        self.logger_file = None
        # Debug switch
        self.debug = False

        # SSL/TLS verification
        # Set this to false to skip verifying SSL certificate when calling API
        # from https server.
        self.verify_ssl = False
        # Set this to customize the certificate file to verify the peer.
        self.ssl_ca_cert = None
        # client certificate file
        self.cert_file = None
        # client key file
        self.key_file = None
        # Set this to True/False to enable/disable SSL hostname verification.
        self.assert_hostname = None

        # Proxy URL
        self.proxy = None
    


#  Copyright (c) 2020. Brendan Johnson. All Rights Reserved.

#import connect
#import config

class APIKeys:
    def __init__(self, config, connection):
        self._config=config
        self._connection = connection
    ##APIKeys
    def Current(self):
        return self._connection.get(url='/apikeys/current')
    def modifyCurrent(self, payload):
        return self._connection.post(url='/apikeys/current', data=payload)
    def currentSecretKey(self, payload):
        return self._connection.post(url='/apikeys/current/secretkey', data=payload)
    def describe(self, apikeyID):
        return self._connection.get(url='/apikeys/{apiKeyID}'.format(apiKeyID=apikeyID))
    def modify(self, apikeyID, payload):
        return self._connection.post(url='/apikeys/{apiKeyID}'.format(apiKeyID=apikeyID), data=payload)
    def delete(self, apikeyID):
        return self._connection.delete(url='/apikeys/{apiKeyID}'.format(apiKeyID=apikeyID))
    def generateSecret(self, apikeyID, payload):
        return self._connection.post(url='/apikeys/{apiKeyID}/secretkey'.format(apiKeyID=apikeyID), data=payload)
    def list(self):
        return self._connection.get(url='/apikeys')
    def create(self, payload):
        return self._connection.post(url='/apikeys', data=payload)
    def search(self, payload):
        return self._connection.post(url='/apikeys/search', data=payload)





#  Copyright (c) 2020. Brendan Johnson. All Rights Reserved.

#import connect
#import config

class Tenants:
    def __init__(self, config, connection):
        self._config=config
        self._connection = connection
    ##SystemSettings
    def list(self):
        return self._connection.get(url='/tenants')
    def modify(self, tenantID, payload):
        return self._connection.post(url='/tenants/{tenantID}'.format(tenantID=tenantID), data=payload)
    def describe(self, tenantID):
        return self._connection.get(url='/tenants/{tenantID}'.format(tenantID=tenantID))
    def delete(self, tenantID):
        return self._connection.delete(url='/tenants/{tenantID}'.format(tenantID=tenantID))
    def create(self, payload):
        return self._connection.post(url='/tenants', data=payload)
    def search(self, payload):
        return self._connection.post(url='/tenants/search', data=payload)
    def createAPIKey(self, tenantID, payload):
        return self._connection.post(url='/tenants/{tenantID}/apikeys'.format(tenantID=tenantID), data=payload)





#  Copyright (c) 2020. Brendan Johnson. All Rights Reserved.

#import connect
#import config

class Policies:
    def __init__(self, config, connection):
        self._config=config
        self._connection = connection
    ##Policies
    def list(self):
        return self._connection.get(url='/policies')
    def create(self, payload):
        return self._connection.post(url='/policies', data=payload)
    def describe(self, id):
        return self._connection.get(url='/policies/{policyID}'.format(id))
    def modify(self, id, payload):
        return self._connection.post(url='/policies/{policyID}'.format(id), data=payload)
    def delete(self, id):
        return self._connection.delete(url='/policies/{policyID}'.format(id))
    def search(self, overrides=False, payload=""):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.post(url='/policies/search', data=payload, params=params)
    # Default Policy Setting
    def describeDefaultSetting(self, name):
        return self._connection.get(url='/policies/default/settings/{name}'.format(name=name))
    def modifyDefaultSetting(self, name, payload):
        return self._connection.post(url='/policies/default/settings/{name}'.format(name=name), data=payload)
    def deleteDefaultSetting(self, name):
        return self._connection.delete(url='/policies/default/settings/{name}'.format(name=name))
    #Default Policy
    def listPolicyDefault(self):
        return self._connection.get(url='/policies/default')
    def modifyPolicyDefault(self, payload):
        return self._connection.post(url='/policies/default', data=payload)
    def describePolicyDefault(self, policyID, name):
        return self._connection.get(url='/policies/{policyID}/settings/{name}'.format(policyID=policyID, name=name))
    def modifyPolicySetting(self, policyID, name, payload):
        return self._connection.post(url='/policies/{policyID}/settings/{name}'.format(policyID=policyID, name=name), data=payload)
    def resetPolicySetting(self, policyID, name):
        return self._connection.delete(url='/policies/{policyID}/settings/{name}'.format(policyID=policyID, name=name))
    #Policy Firewall assignments
    def listFirewallRulesAssignments(self, policyID):
        return self._connection.get(url='/policies/{policyID}/firewall/assignments'.format(policyID=str(policyID)))
    def AddFirewallRuleAssignments(self, policyID, payload):
        return self._connection.post(url='/policies/{policyID}/firewall/assignments'.format(policyID=policyID), data=payload)
    def SetFirewallRulesAssignments(self, policyID, payload):
        return self._connection.put(url='/policies/{policyID}/firewall/assignments'.format(policyID=policyID), data=payload)
    def deleteFirewallRuleAssignments(self, policyID, firewallID):
        return self._connection.delete(url='/policies/{policyID}/firewall/assignments/{firewallRuleID}'.format(policyID=policyID, firewallRuleID=firewallID))
    # Policy Firewall
    def listFirewallRules(self, policyID):
        return self._connection.get(url='/policies/{policyID}/firewall/rules'.format(policyID=policyID))
    def describeFirewallRules(self, policyID, firewallID):
        return self._connection.get(url='/policies/{policyID}/firewall/rules/{firewallRuleID}'.format(policyID=policyID, firewallRuleID=firewallID))
    def modifyFirewallRules(self, policyID, firewallID, payload):
        return self._connection.post(url='/policies/{policyID}/firewall/rules/{firewallRuleID}'.format(policyID=policyID, firewallRuleID=firewallID), data=payload)
    def resetFirewallRules(self, policyID, firewallID):
        return self._connection.delete(url='/policies/{policyID}/firewall/rules/{firewallRuleID}'.format(policyID=policyID, firewallRuleID=firewallID))
    # Integrity monitoring assignments
    def listIntegrityMonitoringRulesAssignments(self, policyID):
        return self._connection.get(url='/policies/{policyID}/integritymonitoring/assignments'.format(policyID=policyID))
    def addIntegrityMonitoringRuleAssignments(self, policyID, payload):
        return self._connection.post(url='/policies/{policyID}/integritymonitoring/assignments'.format(policyID=policyID), data=payload)
    def setIntegrityMonitoringRuleAssignments(self, policyID, payload):
        return self._connection.put(url='/policies/{policyID}/integritymonitoring/assignments'.format(policyID=policyID), data=payload)
    def removeIntegrityMonitoringRuleAssignments(self, policyID, integritymonitoringID):
        return self._connection.delete(url='/policies/{policyID}/integritymonitoring/assignments/{integrityMonitoringRuleID}'.format(policyID=policyID, integrityMonitoringRuleID=integritymonitoringID))
    # Integrity monitoring
    def listIntegrityMonitoringRules(self, policyID):
        return self._connection.get(url='/policies/{policyID}/integritymonitoring/rules'.format(policyID=policyID))
    def describeIntegrityMonitoringRules(self, policyID, integritymonitoringID):
        return self._connection.get(url='/policies/{policyID}/integritymonitoring/rules/{integrityMonitoringRuleID}'.format(policyID=policyID, integrityMonitoringRuleID=integritymonitoringID))
    def modifyIntegrityMonitoringRules(self, policyID, integritymonitoringID, payload):
        return self._connection.post(url='/policies/{policyID}/integritymonitoring/rules/{integrityMonitoringRuleID}'.format(policyID=policyID, integrityMonitoringRuleID=integritymonitoringID), data=payload)
    def deleteIntegrityMonitoringRules(self, policyID, integritymonitoringID):
        return self._connection.delete(url='/policies/{policyID}/integritymonitoring/rules/{integrityMonitoringRuleID}'.format(policyID=policyID, integrityMonitoringRuleID=integritymonitoringID))
    # Intrusion Prevention assignments
    def listIntrusionPreventionRulesAssignments(self, policyID):
        return self._connection.get(url='/policies/{policyID}/intrusionprevention/assignments'.format(policyID=policyID))
    def AddIntrusionPreventionRuleAssignments(self, policyID, payload):
        return self._connection.post(url='/policies/{policyID}/intrusionprevention/assignments'.format(policyID=policyID), data=payload)
    def SetIntrusionPreventionRulesAssignments(self, policyID, payload):
        return self._connection.put(url='/policies/{policyID}/intrusionprevention/assignments'.format(policyID=policyID), data=payload)
    def deleteIntrusionPreventionRuleAssignments(self, policyID, intrusionpreventionID):
        return self._connection.delete(url='/policies/{policyID}/intrusionprevention/assignments/{intrusionPreventionRuleID}'.format(policyID=policyID, intrusionPreventionRuleID=intrusionpreventionID))
    # Intrusion Prevention
    def listIntrusionPreventionRules(self, policyID):
        return self._connection.get(url='/policies/{policyID}/intrusionprevention/rules'.format(policyID=policyID))
    def describeIntrusionPreventionRules(self, policyID, intrusionpreventionID):
        return self._connection.get(url='/policies/{policyID}/intrusionprevention/rules/{intrusionPreventionRuleID}'.format(policyID=policyID, intrusionPreventionRuleID=intrusionpreventionID))
    def modifyIntrusionPreventionRules(self, policyID, intrusionpreventionID, payload):
        return self._connection.post(url='/policies/{policyID}/intrusionprevention/rules/{intrusionPreventionRuleID}'.format(policyID=policyID, intrusionPreventionRuleID=intrusionpreventionID), data=payload)
    def resetIntrusionPreventionRules(self, policyID, intrusionpreventionID):
        return self._connection.delete(url='/policies/{policyID}/intrusionprevention/rules/{intrusionPreventionRuleID}'.format(policyID=policyID, intrusionPreventionRuleID=intrusionpreventionID))
    # Intrusion Prevention application
    def listIntrusionPreventionApplication(self, policyID):
        return self._connection.get(url='/policies/{policyID}/intrusionprevention/applicationtypes'.format(policyID=policyID))
    def describeIntrusionPreventionApplication(self, policyID, applicationID):
        return self._connection.get(url='/policies/{policyID}/intrusionprevention/applicationtypes/{applicationTypeID}'.format(policyID=policyID, applicationTypeID=applicationID))
    def modifyIntrusionPreventionApplication(self, policyID, applicationID, payload):
        return self._connection.post(url='/policies/{policyID}/intrusionprevention/applicationtypes/{applicationTypeID}'.format(policyID=policyID, applicationTypeID=applicationID), data=payload)
    def resetIntrusionPreventionApplication(self, policyID, applicationID):
        return self._connection.delete(url='/policies/{policyID}/intrusionprevention/applicationtypes/{applicationTypeID}'.format(policyID=policyID, applicationTypeID=applicationID))
    #Log inspection assignments
    def listLogInspectionRulesAssignments(self, policyID):
        return self._connection.get(url='/policies/{policyID}/loginspection/assignments'.format(policyID=policyID))
    def AddLogInspectionRuleAssignments(self, policyID, payload):
        return self._connection.post(url='/policies/{policyID}/loginspection/assignments'.format(policyID=policyID), data=payload)
    def SetLogInspectionRulesAssignments(self, policyID, payload):
        return self._connection.put(url='/policies/{policyID}/loginspection/assignments'.format(policyID=policyID), data=payload)
    def deleteLogInspectionRuleAssignments(self, policyID, loginspectionID):
        return self._connection.delete(url='/policies/{policyID}/loginspection/assignments/{logInspectionRuleID}'.format(policyID=policyID, logInspectionRuleID=loginspectionID))
    #Log Inspection
    def listLogInspection(self, policyID):
        return self._connection.get(url='/policies/{policyID}/loginspection/rules'.format(policyID=policyID))
    def describeLogInspection(self, policyID, applicationD):
        return self._connection.get(url='/policies/{policyID}/loginspection/rules/{logInspectionRuleID}'.format(policyID=policyID, logInspectionRuleID=applicationD))
    def modifyLogInspection(self, policyID, applicationD, payload):
        return self._connection.post(url='/policies/{policyID}/loginspection/rules/{logInspectionRuleID}'.format(policyID=policyID, logInspectionRuleID=applicationD), data=payload)
    def resetLogInspection(self, policyID, loginspectionID):
        return self._connection.delete(url='/policies/{policyID}/loginspection/rules/{logInspectionRuleID}'.format(policyID=policyID, logInspectionRuleID=applicationD))





#  Copyright (c) 2020. Brendan Johnson. All Rights Reserved.
#import connect
#import config

class Antimalware:
    def __init__(self, config, connection):
        self._config=config
        self._connection = connection
    ##Antimalware config
    def list(self):
        return self._connection.get(url='/antimalwareconfigurations')
    def create(self, payload):
        return self._connection.post(url='/antimalwareconfigurations', data=payload)
    def describe(self, antimalwareID):
        return self._connection.get(url='/antimalwareconfigurations/{antiMalwareID}'.format(antiMalwareID=antimalwareID))
    def modify(self, antimalwareID, payload):
        return self._connection.post(url='/antimalwareconfigurations/{antiMalwareID}'.format(antiMalwareID=antimalwareID), data=payload)
    def delete(self, antimalwareID):
        return self._connection.delete(url='/antimalwareconfigurations/{antiMalwareID}'.format(antiMalwareID=antimalwareID))
    def search(self, payload):
        return self._connection.post(url='/antimalwareconfigurations/search', data=payload)
    ##Directory lists
    def listdirectorylists(self):
        return self._connection.get(url='/directorylists')
    def createdirectorylist(self, payload):
        return self._connection.post(url='/directorylists', data=payload)
    def describedirectorylist(self, directoryListID):
        return self._connection.get(url='/directorylists/{directoryListID}'.format(directoryListID=directoryListID))
    def modifydirectorylist(self, directoryListID, payload):
        return self._connection.post(url='/directorylists/{directoryListID}'.format(directoryListID=directoryListID), data=payload)
    def deletedirectorylist(self, directoryListID):
        return self._connection.delete(url='/directorylists/{directoryListID}'.format(directoryListID=directoryListID))
    def searchdirectorylist(self, payload):
        return self._connection.post(url='/directorylists/search', data=payload)
    ##File Extension
    def listfileExtensionlists(self):
        return self._connection.get(url='/fileextensionlists')
    def createdfileExtensionlist(self, payload):
        return self._connection.post(url='/fileextensionlists', data=payload)
    def describefileExtensionlist(self, fileExtensionListID):
        return self._connection.get(url='/fileextensionlists/{fileExtensionListID}'.format(fileExtensionListID=fileExtensionListID))
    def modifyfileExtensionlist(self, fileExtensionListID, payload):
        return self._connection.post(url='/fileextensionlists/{fileExtensionListID}'.format(fileExtensionListID=fileExtensionListID), data=payload)
    def deletefileExtensionlist(self, fileExtensionListID):
        return self._connection.delete(url='/fileextensionlists/{fileExtensionListID}'.format(fileExtensionListID=fileExtensionListID))
    def searchfileExtensionlist(self, payload):
        return self._connection.post(url='/fileextensionlists/search', data=payload)
    ##File
    def listfilelists(self):
        return self._connection.get(url='/filelists')
    def createdfilelist(self, payload):
        return self._connection.post(url='/filelists', data=payload)
    def describefilelist(self, fileListID):
        return self._connection.get(url='/filelists/{fileListID}'.format(fileListID=fileListID))
    def modifyfilelist(self, fileListID, payload):
        return self._connection.post(url='/filelists/{fileListID}'.format(fileListID=fileListID), data=payload)
    def deletefilelist(self, fileListID):
        return self._connection.delete(url='/filelists/{fileListID}'.format(fileListID=fileListID))
    def searchfilelist(self, payload):
        return self._connection.post(url='/filelists/search', data=payload)
    ##Schedules
    def listschedules(self):
        return self._connection.get(url='/schedules')
    def createdschedules(self, payload):
        return self._connection.post(url='/schedules', data=payload)
    def describeschedule(self, schedulesID):
        return self._connection.get(url='/schedules/{scheduleID}'.format(scheduleID=schedulesID))
    def modifyschedule(self, schedulesID, payload):
        return self._connection.post(url='/schedules/{scheduleID}'.format(scheduleID=schedulesID), data=payload)
    def deleteschedule(self, schedulesID):
        return self._connection.delete(url='/schedules/{scheduleID}'.format(scheduleID=schedulesID))
    def searchschedule(self, payload):
        return self._connection.post(url='/schedules/search', data=payload)





#  Copyright (c) 2020. Brendan Johnson. All Rights Reserved.

import requests
import json
import urllib3
import time
from DeepSecurity.__version__ import __version__
urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
class Connection:
    def __init__(self, config):
        self._config = config
        self._session = None
        self._retries = 0
        self._MAX_RETRIES = 12
    def _buildheaders(self):
        return { 'api-secret-key': self._config.api_key,
                               'api-version': 'v1',
                               'Content-Type': 'application/json',
                 'User-Agent': 'ds-sdk-mini ' + __version__ }
    def _setupSession(self):
        self._retries = 0
        if self._session is None:
            self._session = requests.Session()
            self._session .headers.update(self._buildheaders())
        return

    def get(self, url, params=None):
        self._setupSession()
        resp = self._session.get(self._config.host + url, verify=self._config.verify_ssl, params=params)
        if resp.status_code == 200:
            return json.loads(resp.content.decode('utf-8'))
        elif resp.status_code == 429 and self._retries < self._MAX_RETRIES:
            self._retries += 1
            exp_backoff = (2**(self._retries+3))/1000
            time.sleep(exp_backoff)
            self.get(url=url, params=params)
        return resp

    def delete(self, url,  params=None):
        self._setupSession()
        resp = self._session.delete(self._config.host + url, verify=self._config.verify_ssl, params=params)
        if resp.status_code == 200:
            return "Success"
        elif resp.status_code == 429 and self._retries < self._MAX_RETRIES:
            self._retries += 1
            exp_backoff = (2**(self._retries+3))/1000
            time.sleep(exp_backoff)
            self.delete(url=url, params=params)
        return resp

    def post(self, url, data,  params=None):
        self._setupSession()
        resp = self._session.post(self._config.host + url, verify=self._config.verify_ssl, json=data, params=params)
        if resp.status_code == 200:
            return json.loads(resp.content.decode('utf-8'))
        elif resp.status_code == 429 and self._retries < self._MAX_RETRIES:
            self._retries += 1
            exp_backoff = (2**(self._retries+3))/1000
            time.sleep(exp_backoff)
            self.post(ur=url, data=data, params=params)
        return resp

    def put(self, url, data,  params=None):
        self._setupSession()
        resp = self._session.put(self._config.host + url, verify=self._config.verify_ssl, json=data, params=params)
        if resp.status_code == 200:
            return json.loads(resp.content.decode('utf-8'))
        elif resp.status_code == 429 and self._retries < self._MAX_RETRIES:
            self._retries += 1
            exp_backoff = (2**(self._retries+3))/1000
            time.sleep(exp_backoff)
            self.put(url=url, data=data, params=params)
        return resp


#  Copyright (c) 2020. Brendan Johnson. All Rights Reserved.

#import connect
#import config

class AgentDeploymentScripts:
    def __init__(self, config, connection):
        self._config=config
        self._connection = connection

    def generate(self, payload):
        return self._connection.post(url='/agentdeploymentscripts', data=payload)


#  Copyright (c) 2020. Brendan Johnson. All Rights Reserved.
#import connect
#import config

class LogInspectionRules:
    def __init__(self, config, connection):
        self._config=config
        self._connection = connection
    ##LogInspection rules
    def list(self):
        return self._connection.get(url='/loginspectionrules')
    def create(self, payload):
        return self._connection.post(url='/loginspectionrules', data=payload)
    def describe(self, logInspectionRuleID):
        return self._connection.get(url='/loginspectionrules/{logInspectionRuleID}'.format(logInspectionRuleID=logInspectionRuleID))
    def modify(self, logInspectionRuleID, payload):
        return self._connection.post(url='/loginspectionrules/{logInspectionRuleID}'.format(logInspectionRuleID=logInspectionRuleID), data=payload)
    def delete(self, logInspectionRuleID):
        return self._connection.delete(url='/loginspectionrules/{logInspectionRuleID}'.format(logInspectionRuleID=logInspectionRuleID))
    def search(self, payload):
        return self._connection.post(url='/loginspectionrules/search', data=payload)


#  Copyright (c) 2020. Brendan Johnson. All Rights Reserved.
#import connect
#import config

class AwsConnectors:
    def __init__(self, config, connection):
        self._config=config
        self._connection = connection
    ##connectors
    def list(self):
        return self._connection.get(url='/awsconnectors')
    def create(self, payload):
        return self._connection.post(url='/awsconnectors', data=payload)
    def describe(self, connectorID):
        return self._connection.get(url='/awsconnectors/{awsConnectorID}'.format(awsConnectorID=connectorID))
    def modify(self, connectorID, payload):
        return self._connection.post(url='/awsconnectors/{awsConnectorID}'.format(awsConnectorID=connectorID), data=payload)
    def delete(self, connectorID):
        return self._connection.delete(url='/awsconnectors/{awsConnectorID}'.format(awsConnectorID=connectorID))
    def search(self, payload):
        return self._connection.post(url='/awsconnectors/search', data=payload)
    def Settings(self):
        return self._connection.get(url='/awsconnectorsettings')


#  Copyright (c) 2020. Brendan Johnson. All Rights Reserved.
#import connect
#import config

class Administrators:
    def __init__(self, config, connection):
        self._config=config
        self._connection = connection
    ##Administrators
    def list(self):
        return self._connection.get(url='/administrators')
    def create(self, payload):
        return self._connection.post(url='/administrators', data=payload)
    def describe(self, adminID):
        return self._connection.get(url='/administrators/{administratorID}'.format(administratorID=adminID))
    def modify(self, adminID, payload):
        return self._connection.post(url='/administrators/{administratorID}'.format(administratorID=adminID), data=payload)
    def delete(self, adminID):
        return self._connection.delete(url='/administrators/{administratorID}'.format(administratorID=adminID))
    def search(self, payload):
        return self._connection.post(url='/administrators/search', data=payload)
    #Roles
    def listRoles(self):
        return self._connection.get(url='/roles')
    def createRole(self, payload):
        return self._connection.post(url='/roles', data=payload)
    def searchRole(self, payload):
        return self._connection.post(url='/roles/search', data=payload)
    def describeRole(self, roleID):
        return self._connection.get(url='/roles/{roleID}'.format(roleID=roleID))
    def modifyRole(self, roleID, payload):
        return self._connection.post(url='/roles/{roleID}'.format(roleID=roleID), data=payload)
    def deleteRole(self, roleID):
        return self._connection.delete(url='/roles/{roleID}'.format(roleID=roleID))




#  Copyright (c) 2020. Brendan Johnson. All Rights Reserved.

#import connect
#import config

class AgentVersionControl:
    def __init__(self, config, connection):
        self._config=config
        self._connection = connection
    ##AgentVersionControl
    def describe(self, profileID):
        return self._connection.get(url='/agentversioncontrolprofiles/{agentVersionControlProfileID}/agentversioncontrols'.format(agentVersionControlProfileID=profileID))
    def modify(self, profileID, payload):
        return self._connection.post(url='/agentversioncontrolprofiles/{agentVersionControlProfileID}/agentversioncontrols'.format(agentVersionControlProfileID=profileID), data=payload)
    def search(self, profileID, payload):
        return self._connection.post(url='/agentversioncontrolprofiles/{agentVersionControlProfileID}/agentversioncontrols/search'.format(agentVersionControlProfileID=profileID), data=payload)
    def describeControl(self, profileID, agentVersionControlID):
        return self._connection.get(url='/agentversioncontrolprofiles/{agentVersionControlProfileID}/agentversioncontrols/{agentVersionControlID}'.format(agentVersionControlProfileID=profileID, agentVersionControlID=agentVersionControlID))
    def listProfiles(self):
        return self._connection.get(url='/agentversioncontrolprofiles')
    def describeProfile(self, profileID):
        return self._connection.get(url='/agentversioncontrolprofiles/{agentVersionControlProfileID}'.format(agentVersionControlProfileID=profileID))






#  Copyright (c) 2020. Brendan Johnson. All Rights Reserved.

#import connect
#import config

class EventBasedTasks:
    def __init__(self, config, connection):
        self._config=config
        self._connection = connection
    ##EventBasedTasks
    def list(self):
        return self._connection.get(url='/eventbasedtasks')
    def create(self, payload):
        return self._connection.post(url='/eventbasedtasks', data=payload)
    def search(self, payload):
        return self._connection.post(url='/eventbasedtasks/search', data=payload)
    def describe(self, eventbasedtaskID):
        return self._connection.get(url='/eventbasedtasks/{eventBasedTaskID}'.format(eventBasedTaskID=eventbasedtaskID))
    def modify(self, eventbasedtaskID, payload):
        return self._connection.post(url='/eventbasedtasks/{eventBasedTaskID}'.format(eventBasedTaskID=eventbasedtaskID), data=payload)
    def delete(self, eventbasedtaskID):
        return self._connection.delete(url='/eventbasedtasks/{eventBasedTaskID}'.format(eventBasedTaskID=eventbasedtaskID))



#  Copyright (c) 2020. Brendan Johnson. All Rights Reserved.
#import connect
#import config

class IntegrityMonitoring:
    def __init__(self, config, connection):
        self._config=config
        self._connection = connection
    ##IntegrityMonitoring config
    def list(self):
        return self._connection.get(url='/integritymonitoringrules')
    def create(self, payload):
        return self._connection.post(url='/integritymonitoringrules', data=payload)
    def describe(self, integrityMonitoringRuleID):
        return self._connection.get(url='/integritymonitoringrules/{integrityMonitoringRuleID}'.format(integrityMonitoringRuleID=integrityMonitoringRuleID))
    def modify(self, integrityMonitoringRuleID, payload):
        return self._connection.post(url='/integritymonitoringrules/{integrityMonitoringRuleID}'.format(integrityMonitoringRuleID=integrityMonitoringRuleID), data=payload)
    def delete(self, integrityMonitoringRuleID):
        return self._connection.delete(url='/integritymonitoringrules/{integrityMonitoringRuleID}'.format(integrityMonitoringRuleID=integrityMonitoringRuleID))
    def search(self, payload):
        return self._connection.post(url='/integritymonitoringrules/search', data=payload)


#  Copyright (c) 2020. Brendan Johnson. All Rights Reserved.

#import connect
#import config

class Computers:
    def __init__(self, config, connection):
        self._config=config
        self._connection = connection
        self._epxand = ["none", "all", "computerStatus", "tasks", "securityUpdates", "computerSettings",
                        "allSecurityModules", "antiMalware", "webReputation", "activityMonitoring", "firewall",
                        "intrusionPrevention", "integrityMonitoring", "logInspection", "applicationControl", "SAP",
                        "interfaces", "ESXSummary", "allVirtualMachineSummaries", "azureARMVirtualMachineSummary",
                        "azureVMVirtualMachineSummary", "ec2VirtualMachineSummary", "noConnectorVirtualMachineSummary",
                        "vmwareVMVirtualMachineSummary", "vcloudVMVirtualMachineSummary", "workspaceVirtualMachineSummary",
                        "gcpVirtualMachineSummary"]
    def _processExpands(self, expands):
        rtv = []
        split = expands.split(",")
        for expand in split:
            added=False
            lowerCase = expand.lower()
            for ex in self._epxand:
                if ex.lower() == lowerCase:
                    rtv.append(ex)
                    added = True
                    break
            if not added:
                ##Unknown expands - maybe newer than SDK?
                rtv.append(expand)
        return rtv

    ##Computers
    def list(self, expand=None, overrides=None):
        params = {}
        if expand:
            params['expand'] = self._processExpands(expands=expand)
        if overrides:
            params['overrides'] = overrides
        return self._connection.get(url='/computers', params=params)
    def describe(self, id, expand=None, overrides=None):
        params = {}
        if expand:
            params['expand'] = self._processExpands(expands=expand)
        if overrides:
            params['overrides'] = overrides
        return self._connection.get(url='/computers/{computerID}'.format(computerID=id), params=params)
    def modify(self, id, expand=None, overrides=None, payload=None):
        params = {}
        if expand:
            params['expand'] = self._processExpands(expands=expand)
        if overrides:
            params['overrides'] = overrides
        return self._connection.post(url='/computers/{computerID}'.format(computerID=id), data=payload, params=params)
    def delete(self, id):
        return self._connection.delete(url='/computers/{computerID}'.format(computerID=id))
    def describeSetting(self, id, setting, overrides=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.get(url='/computers/{computerID}/settings/{name}'.format(computerID=id, name=setting), params=params)
    def modifySetting(self, id, setting, overrides=None, payload=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.post(url='/computers/{computerID}/settings/{name}'.format(computerID=id, name=setting), data=payload, params=params)
    def resetSetting(self, id, setting, overrides=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.delete(url='/computers/{computerID}/settings/{name}'.format(computerID=id, name=setting), params=params)
    def create(self, expand=None, overrides=None, payload=None):
        params = {}
        if expand:
            params['expand'] = expand
        if overrides:
            params['overrides'] = overrides
        return self._connection.post(url='/computers' , data=payload, params=params)
    def search(self, expand=None, overrides=None, payload=None):
        computers = None
        params = {}
        if expand:
            params['expand'] = self._processExpands(expands=expand)
        if overrides:
            params['overrides'] = overrides
        rtv = self._connection.post(url='/computers/search', data=payload, params=params)
        if 'computers' not in rtv:
            return rtv
        computers = rtv['computers']
        while len(rtv['computers']) > 0:
            if 'idTest' in payload['searchCriteria'][0]:
                if payload['searchCriteria'][0]['idTest'] == 'equal' or payload['searchCriteria'][0]['idTest'] == 'not-equal':
                    return computers
                if payload['searchCriteria'][0]['idTest'] == 'greater-than-or-equal':
                    payload['searchCriteria'][0]['idValue'] = int(computers[len(computers) - 1]['ID']) + 1
                if payload['searchCriteria'][0]['idTest'] == 'less-than-or-equal':
                    payload['searchCriteria'][0]['idValue'] = int(computers[len(computers) - 1]['ID']) - 1
                if payload['searchCriteria'][0]['idTest'] == 'less-than' or payload['searchCriteria'][0]['idTest'] == 'greater-than':
                    payload['searchCriteria'][0]['idValue'] = int(computers[len(computers) - 1]['ID'])
                rtv = self._connection.post(url='/computers/search', data=payload, params=params)
            computers.extend(rtv['computers'])
        return computers


    ##Computers Firewall Rule Assignments
    def listFirewallAssignment(self, id, overrides=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.get(url='/computers/{computerID}/firewall/assignments'.format(computerID=id), params=params)
    def addFirewallAssignment(self, id, overrides=None, payload=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.post(url='/computers/{computerID}/firewall/assignments'.format(computerID=id), data=payload, params=params)
    def setFirewallAssignment(self, id, overrides=None, payload=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.put(url='/computers/{computerID}/firewall/assignments'.format(computerID=id), data=payload, params=params)
    def deleteFirewallAssignment(self, id, ruleID, overrides=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.delete(url='/computers/{computerID}/firewall/assignments/{firewallRuleID}'.format(computerID=id, firewallRuleID=ruleID), params=params)
    ##Computers Firewall Rule
    def listFirewallRules(self, id, overrides=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.get(url='/computers/{computerID}/firewall/rules'.format(computerID=id), params=params)
    def describeFirewallRules(self, id, firewallRuleId, overrides=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.get(url='/computers/{computerID}/firewall/rules/{firewallRuleID}'.format(computerID=id, firewallRuleID=firewallRuleId), params=params)
    def modifyFirewallRules(self, id, firewallRuleId, overrides=None, payload=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.post(url='/computers/{computerID}/firewall/rules/{firewallRuleID}'.format(computerID=id, firewallRuleID=firewallRuleId), data=payload, params=params)
    def resetFirewallRules(self, id, firewallRuleId, overrides=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.delete(url='/computers/{computerID}/firewall/rules/{firewallRuleID}'.format(computerID=id, firewallRuleID=firewallRuleId), params=params)
    #IntegrityMonitoring
    def listIntegrityMonitoringRules(self, id, overrides=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.get(url='/computers/{computerID}/integritymonitoring/rules'.format(computerID=id), params=params)
    def describeIntegrityMonitoringRules(self, id, integritymonitoringlRuleId, overrides=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.get(url='/computers/{computerID}/integritymonitoring/rules/{integrityMonitoringRuleID}'.format(computerID=id, integrityMonitoringRuleID=integritymonitoringlRuleId), params=params)
    def modifyIntegrityMonitoringRules(self, id, integritymonitoringlRuleId, overrides=None, payload=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.post(url='/computers/{computerID}/integritymonitoring/rules/{integrityMonitoringRuleID}'.format(computerID=id, integrityMonitoringRuleID=integritymonitoringlRuleId), data=payload, params=params)
    def deleteIntegrityMonitoringRules(self, id, integritymonitoringlRuleId, overrides=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.delete(url='/computers/{computerID}/integritymonitoring/rules/{integrityMonitoringRuleID}'.format(computerID=id, integrityMonitoringRuleID=integritymonitoringlRuleId), params=params)

    # IntegrityMonitoring Assignments
    def listIntegrityMonitoringAssignments(self, id, overrides=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.get(url='/computers/{computerID}/integritymonitoring/assignments'.format(computerID=id), params=params)
    def setIntegrityMonitoringAssignments(self, id, overrides=None, payload=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.put(url='/computers/{computerID}/integritymonitoring/assignments'.format(computerID=id), data=payload,params=params)
    def addIntegrityMonitoringAssignments(self, id, overrides=None, payload=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.post(url='/computers/{computerID}/integritymonitoring/assignments'.format(computerID=id), data=payload,params=params)
    def deleteIntegrityMonitoringAssignments(self, id, integritymonitoringlRuleId, overrides=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.delete(url='/computers/{computerID}/integritymonitoring/assignments/{integrityMonitoringRuleID}'.format(computerID=id, integrityMonitoringRuleID=integritymonitoringlRuleId), params=params)
    #Intrusion Prevention - assignments
    def listIntrusionPreventionAssignment(self, id, overrides=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.get(url='/computers/{computerID}/intrusionprevention/assignments'.format(computerID=id), params=params)
    def assignIntrusionPreventionAssignment(self, id, overrides=None, payload=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.post(url='/computers/{computerID}/intrusionprevention/assignments'.format(computerID=id), data=payload, params=params)
    def createIntrusionPreventionAssignment(self, id, overrides=None, payload=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.put(url='/computers/{computerID}/intrusionprevention/assignments'.format(computerID=id), data=payload, params=params)
    def deleteComputerIntrusionPreventionAssignment(self, id, ruleID, overrides=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.delete(url='/computers/{computerID}/intrusionprevention/assignments/{intrusionPreventionRuleID}'.format(computerID=id, intrusionPreventionRuleID=ruleID), params=params)
    #Intrusion Prevention - application type
    def listIntrusionPreventionApplicationTypes(self, id, overrides=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.get(url='/computers/{computerID}/intrusionprevention/applicationtypes'.format(computerID=id), params=params)
    def describeIntrusionPreventionApplicationTypes(self, id, intrusionPreventionApplicationTypesId, overrides=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.get(url='/computers/{computerID}/intrusionprevention/applicationtypes/{applicationTypeID}'.format(computerID=id, applicationTypeID=intrusionPreventionApplicationTypesId), params=params)
    def modifyIntrusionPreventionApplicationTypes(self, id, intrusionPreventionApplicationTypesId, overrides=None, payload=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.post(url='/computers/{computerID}/intrusionprevention/applicationtypes/{applicationTypeID}'.format(computerID=id, applicationTypeID=intrusionPreventionApplicationTypesId), data=payload, params=params)
    def deleteIntrusionPreventionApplicationTypes(self, id, intrusionPreventionApplicationTypesId, overrides=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.delete(url='/computers/{computerID}/intrusionprevention/applicationtypes/{applicationTypeID}'.format(computerID=id, applicationTypeID=intrusionPreventionApplicationTypesId), params=params)
    #Intrusion Prevention - Rule
    def listIntrusionPreventionRules(self, id, overrides=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.get(url='/computers/{computerID}/intrusionprevention/rules'.format(computerID=id), params=params)
    def describeIntrusionPreventionRule(self, id, ruleID, overrides=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.get(url='/computers/{computerID}/intrusionprevention/rules/{intrusionPreventionRuleID}'.format(computerID=id, intrusionPreventionRuleID=ruleID), params=params)
    def modifyIntrusionPreventionRule(self, id, ruleID, overrides=None, payload=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.post(url='/computers/{computerID}/intrusionprevention/rules/{intrusionPreventionRuleID}'.format(computerID=id, intrusionPreventionRuleID=ruleID), data=payload, params=params)
    def deleteIntrusionPreventionRules(self, id, ruleID, overrides=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.delete(url='/computers/{computerID}/intrusionprevention/rules/{intrusionPreventionRuleID}'.format(computerID=id, intrusionPreventionRuleID=ruleID), params=params)
    #Log Inspection assignment
    def listLogInspectionAssignment(self, id, overrides=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.get(url='/computers/{computerID}/loginspection/assignments'.format(computerID=id), params=params)
    def assignLogInspectionAssignment(self, id, overrides=None, payload=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.post(url='/computers/{computerID}/loginspection/assignments'.format(computerID=id), params=params, data=payload)
    def setLogInspectionAssignment(self, id, overrides=None, payload=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.put(url='/computers/{computerID}/loginspection/assignments'.format(computerID=id), params=params, data=payload)
    def deleteLogInspectionAssignment(self, id, ruleID, overrides=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.delete(url='/computers/{computerID}/loginspection/assignments/{logInspectionRuleID}'.format(computerID=id, logInspectionRuleID=ruleID), params=params)
    #ILog Inspection  - rules
    def listLogInspectionRules(self, id, overrides=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.get(url='/computers/{computerID}/loginspection/rules'.format(computerID=id), params=params)
    def describeLogInspectionRule(self, id, ruleID, overrides=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.get(url='/computers/{computerID}/loginspection/rules/{logInspectionRuleID}'.format(computerID=id, logInspectionRuleID=ruleID), params=params)
    def modifyLogInspectionRule(self, id, ruleID, overrides=None, payload=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.post(url='/computers/{computerID}/loginspection/rules/{logInspectionRuleID}'.format(computerID=id, logInspectionRuleID=ruleID), data=payload, params=params)
    def deleteLogInspectionRule(self, id, ruleID, overrides=None):
        params = {}
        if overrides:
            params['overrides'] = overrides
        return self._connection.delete(url='/computers/{computerID}/loginspection/rules/{logInspectionRuleID}'.format(computerID=id, logInspectionRuleID=ruleID), params=params)






#  Copyright (c) 2020. Brendan Johnson. All Rights Reserved.

#import connect
#import config

class ComputerGroups:
    def __init__(self, config, connection):
        self._config=config
        self._connection = connection
    ##ComputerGroups
    def list(self):
        return self._connection.get(url='/computergroups')
    def create(self, payload):
        return self._connection.post(url='/computergroups', data=payload)
    def search(self, payload):
        return self._connection.post(url='/computergroups/search', data=payload)
    def describe(self, groupID):
        return self._connection.get(url='/computergroups/{computerGroupID}'.format(computerGroupID=groupID))
    def modify(self, id, payload):
        return self._connection.post(url='/computergroups/{computerGroupID}'.format(computerGroupID=id), data=payload)
    def delete(self, id):
        return self._connection.delete(url='/computergroups/{computerGroupID}'.format(computerGroupID=id))






#  Copyright (c) 2020. Brendan Johnson. All Rights Reserved.
#import connect
#import config

class firewall:
    def __init__(self, config, connection):
        self._config=config
        self._connection = connection
    ##Firewall rules
    def list(self):
        return self._connection.get(url='/firewallrules')
    def create(self, payload):
        return self._connection.post(url='/firewallrules', data=payload)
    def describe(self, firewallRuleID):
        return self._connection.get(url='/firewallrules/{firewallRuleID}'.format(firewallRuleID=firewallRuleID))
    def modify(self, firewallRuleID, payload):
        return self._connection.post(url='/firewallrules/{firewallRuleID}'.format(firewallRuleID=firewallRuleID), data=payload)
    def delete(self, firewallRuleID):
        return self._connection.delete(url='/firewallrules/{firewallRuleID}'.format(firewallRuleID=firewallRuleID))
    def search(self, payload):
        return self._connection.post(url='/firewallrules/search', data=payload)
    ##Interface Type
    def listInterfaceTypes(self, policyID):
        return self._connection.get(url='/policies/{policyID}/interfacetypes'.format(policyID=policyID))
    def createInterfaceType(self,policyID, payload):
        return self._connection.post(url='/policies/{policyID}/interfacetypes'.format(policyID=policyID), data=payload)
    def describeInterfaceType(self, policyID, interfaceTypeID):
        return self._connection.get(url='/policies/{policyID}/interfacetypes/{interfaceTypeID}'.format(policyID=policyID, interfaceTypeID=interfaceTypeID))
    def modifyInterfaceType(self, policyID, interfaceTypeID, payload):
        return self._connection.post(url='/policies/{policyID}/interfacetypes/{interfaceTypeID}'.format(policyID=policyID, interfaceTypeID=interfaceTypeID), data=payload)
    def deleteInterfaceType(self,  policyID, interfaceTypeID,):
        return self._connection.delete(url='/policies/{policyID}/interfacetypes/{interfaceTypeID}'.format(policyID=policyID, interfaceTypeID=interfaceTypeID))
    def searchInterfaceTypes(self, policyID, payload):
        return self._connection.post(url='/policies/{policyID}/interfacetypes/search'.format(policyID=policyID), data=payload)
    ##Firewall IP list
    def listIPLists(self):
        return self._connection.get(url='/iplists')
    def createiplists(self, payload):
        return self._connection.post(url='/iplists', data=payload)
    def describeIPList(self, ipListID):
        return self._connection.get(url='/iplists/{ipListID}'.format(ipListID))
    def modifyIPList(self, ipListID, payload):
        return self._connection.post(url='/iplists/{ipListID}'.format(ipListID), data=payload)
    def deleteIPList(self, ipListID):
        return self._connection.delete(url='/iplists/{ipListID}'.format(ipListID))
    def searchIPLists(self, payload):
        return self._connection.post(url='/iplists/search', data=payload)
    ##Firewall MAC list
    def listMacLists(self):
        return self._connection.get(url='/maclists')
    def createmaclists(self, payload):
        return self._connection.post(url='/maclists', data=payload)
    def describemacList(self, macListID):
        return self._connection.get(url='/maclists/{macListID}'.format(macListID=macListID))
    def modifymacList(self, macListID, payload):
        return self._connection.post(url='/maclists/{macListID}'.format(macListID=macListID), data=payload)
    def deletemacList(self, macListID):
        return self._connection.delete(url='/maclists/{macListID}'.format(macListID=macListID))
    def searchmacLists(self, payload):
        return self._connection.post(url='/maclists/search', data=payload)
    ##Firewall Port list
    def listPortLists(self):
        return self._connection.get(url='/portlists')
    def createportlists(self, payload):
        return self._connection.post(url='/portlists', data=payload)
    def describeportList(self, portListID):
        return self._connection.get(url='/portlists/{portListID}'.format(portListID=portListID))
    def modifyportList(self, portListID, payload):
        return self._connection.post(url='/portlists/{portListID}'.format(portListID=(portListID)), data=payload)
    def deleteportList(self, portListID):
        return self._connection.delete(url='/portlists/{portListID}'.format(portListID=portListID))
    def searchportLists(self, payload):
        return self._connection.post(url='/portlists/search', data=payload)
    ##Firewall Contexts
    def listContexts(self):
        return self._connection.get(url='/contexts')
    def createContext(self, payload):
        return self._connection.post(url='/contexts', data=payload)
    def describeContext(self, contextID):
        return self._connection.get(url='/contexts/{contextID}'.format(contextID=contextID))
    def modifyContext(self, contextID, payload):
        return self._connection.post(uurl='/contexts/{contextID}'.format(contextID=contextID), data=payload)
    def deleteContext(self, contextID):
        return self._connection.delete(url='/contexts/{contextID}'.format(contextID=contextID))
    def searchContexts(self, payload):
        return self._connection.post(url='/contexts/search', data=payload)
    ##Firewall Stateful Configurations
    def listStatefulConfigurations(self):
        return self._connection.get(url='/statefulconfigurations')
    def createStatefulConfiguration(self, payload):
        return self._connection.post(url='/statefulconfigurations', data=payload)
    def describeStatefulConfiguration(self, statefulConfigurationID):
        return self._connection.get(url='/statefulconfigurations/{statefulConfigurationID}'.format(statefulConfigurationID=statefulConfigurationID))
    def modifyStatefulConfiguration(self, statefulConfigurationID, payload):
        return self._connection.post(url='/statefulconfigurations/{statefulConfigurationID}'.format(statefulConfigurationID=statefulConfigurationID), data=payload)
    def deleteStatefulConfiguration(self, statefulConfigurationID):
        return self._connection.delete(url='/statefulconfigurations/{statefulConfigurationID}'.format(statefulConfigurationID=statefulConfigurationID))
    def searchStatefulConfigurations(self, payload):
        return self._connection.post(url='/statefulconfigurations/search', data=payload)






#  Copyright (c) 2020. Brendan Johnson. All Rights Reserved.
#import connect
#import config

class ApplicationControl:
    def __init__(self, config, connection):
        self._config=config
        self._connection = connection
    ##ApplicationControl global rules
    def listGlobalRules(self):
        return self._connection.get(url='/applicationcontrolglobalrules')
    def createGlobalRule(self, payload):
        return self._connection.post(url='/applicationcontrolglobalrules', data=payload)
    def describeGlobalRule(self, ruleID):
        return self._connection.get(url='/applicationcontrolglobalrules/{ruleID}'.format(ruleID=ruleID))
    def modifyGlobalRule(self, ruleID, payload):
        return self._connection.post(url='/applicationcontrolglobalrules/{ruleID}'.format(ruleID=ruleID), data=payload)
    def deleteGlobalRule(self, ruleID):
        return self._connection.delete(url='/applicationcontrolglobalrules/{ruleID}'.format(ruleID=ruleID))
    def searchGlobalRules(self, payload):
        return self._connection.post(url='/applicationcontrolglobalrules/search', data=payload)
    ## ApplicationControl
    def listrulesets(self):
        return self._connection.get(url='/rulesets')
    def createruleset(self, payload):
        return self._connection.post(url='/rulesets', data=payload)
    def describeGlobalRule(self, rulesetID):
        return self._connection.get(url='/rulesets/{rulesetID}'.format(rulesetID=rulesetID))
    def modifyruleset(self, rulesetID, payload):
        return self._connection.post(url='/rulesets/{rulesetID}'.format(rulesetID=rulesetID), data=payload)
    def deleteruleset(self, rulesetID):
        return self._connection.delete(url='/rulesets/{rulesetID}'.format(rulesetID=rulesetID))
    def searchrulesets(self, payload):
        return self._connection.post(url='/rulesets/search', data=payload)
    def listrulesetRules(self, rulesetID):
        return self._connection.get(url='/rulesets/{rulesetID}/rules'.format(rulesetID=rulesetID))
    def describeRulesetRule(self, rulesetID, ruleID):
        return self._connection.get(url='/rulesets/{rulesetID}/rules/{ruleID}'.format(rulesetID=rulesetID,ruleID=ruleID))
    def modifyrulesetRule(self, rulesetID, ruleID, payload):
        return self._connection.post(url='/rulesets/{rulesetID}/rules/{ruleID}'.format(rulesetID=rulesetID,ruleID=ruleID), data=payload)
    def deleterulesetRule(self, rulesetID, ruleID):
        return self._connection.delete(url='/rulesets/{rulesetID}/rules/{ruleID}'.format(rulesetID=rulesetID,ruleID=ruleID))
    def searchrulesetRules(self, rulesetID, payload):
        return self._connection.post(url='/rulesets/{rulesetID}/rules/search'.format(rulesetID=rulesetID), data=payload)
    ## Software Changes
    def listsoftwareChanges(self):
        return self._connection.get(url='/softwarechanges')
    def describesoftwareChange(self, softwareChangeID):
        return self._connection.get(url='/softwarechanges/{softwareChangeID}'.format(softwareChangeID=softwareChangeID))
    def searchsoftwareChanges(self, payload):
        return self._connection.post(url='/softwarechanges/search', data=payload)
    def reviewSoftwareChange(self, payload):
        return self._connection.post(url='/softwarechanges/review', data=payload)
    ## Software Inventories
    def listSoftwareInventories(self):
        return self._connection.get(url='/softwareinventories')
    def createSoftwareInventory(self, payload):
        return self._connection.post(url='/softwareinventories', data=payload)
    def describeSoftwareInventory(self, softwareInventoryID):
        return self._connection.get(url='/softwareinventories/{softwareInventoryID}'.format(softwareInventoryID=softwareInventoryID))
    def deleteSoftwareInventory(self, softwareInventoryID):
        return self._connection.delete(url='/softwareinventories/{softwareInventoryID}'.format(softwareInventoryID=softwareInventoryID))
    def searchSoftwareInventory(self, payload):
        return self._connection.post(url='/softwareinventories/search', data=payload)
    def listSoftwareInventoryItems(self,softwareInventoryID):
        return self._connection.get(uurl='/softwareinventories/{softwareInventoryID}/items'.format(softwareInventoryID=softwareInventoryID))
    def searchSoftwareInventoryItems(self, softwareInventoryID, payload):
        return self._connection.post(url='/softwareinventories/{softwareInventoryID}/items/search'.format(softwareInventoryID=softwareInventoryID), data=payload)
    def describeSoftwareInventoryItem(self,softwareInventoryID, inventoryItemID):
        return self._connection.get(url='/softwareinventories/{softwareInventoryID}/items/{inventoryItemID}'.format(softwareInventoryID=softwareInventoryID, inventoryItemID=inventoryItemID))




#  Copyright (c) 2020. Brendan Johnson. All Rights Reserved.

#import connect
#import config

class APIUsageMetrics:
    def __init__(self, config, connection):
        self._config=config
        self._connection = connection
    ##APIUsageMetrics
    def list(self):
        return self._connection.get(url='/apiusagemetrics')
    def search(self, payload):
        return self._connection.post(url='/apiusagemetrics/search', data=payload)




#  Copyright (c) 2020. Brendan Johnson. All Rights Reserved.


from DeepSecurity.__version__ import __version__
from DeepSecurity.Computers import Computers
from DeepSecurity.config import Config
from DeepSecurity.connect import Connection
from DeepSecurity.ComputerGroups import ComputerGroups
from DeepSecurity.gcpconnector import gcpconnector
from DeepSecurity.AgentDeploymentScripts import AgentDeploymentScripts
from DeepSecurity.Policies import Policies
from DeepSecurity.Administrators import Administrators
from DeepSecurity.AgentDeploymentScripts import AgentDeploymentScripts
from DeepSecurity.APIKey import APIKeys
from DeepSecurity.APIUsageMetrics import APIUsageMetrics
from DeepSecurity.Certificates import Certificates
from DeepSecurity.Contacts import Contacts
from DeepSecurity.EventBasedTasks import EventBasedTasks
from DeepSecurity.ReportTemplates import ReportTemplates
from DeepSecurity.ScheduledTasks import ScheduledTasks
from DeepSecurity.SystemSettings import SystemSettings
from DeepSecurity.Tenants import Tenants
from DeepSecurity.Scripts import Scripts
from DeepSecurity.antimalware import Antimalware
from DeepSecurity.firewall import firewall
from DeepSecurity.IntegrityMonitoring import IntegrityMonitoring
from DeepSecurity.IntrusionPrevention import IntrusionPrevention
from DeepSecurity.LogInspectionRules import LogInspectionRules
from DeepSecurity.applicationControl import ApplicationControl



import setuptools
import sys
from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

install_requires = [
    'requests',
    'urllib3'
]

setup_options = dict(
    name="ds-sdk-mini", # Replace with your own username
    version='0.00.12',
    author="Brendan Johnson",
    author_email="brendan_johnson@trendmicro.com",
    description="A lightweight SDK for Trend Micro Deep Security",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/trendmicro/thus/ds-sdk-mini",
    packages=setuptools.find_packages(),
    classifiers=[
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    install_requires=install_requires,
    python_requires='>=3.6',
)
if 'py2exe' in sys.argv:
    # This will actually give us a py2exe command.
    import py2exe
    # And we have some py2exe specific options.
    setup_options['options'] = {
        'py2exe': {
            'optimize': 0,
            'skip_archive': True,
            'dll_excludes': ['crypt32.dll'],
            'packages': ['requests',
                         'cloudonecli', 'ConfigParser'],
        }
    }



setup(**setup_options)




#  Copyright (c) 2020. Brendan Johnson. All Rights Reserved.

#import connect
#import config

class Certificates:
    def __init__(self, config, connection):
        self._config=config
        self._connection = connection
    ##Certificates
    def describe(self, certID):
        return self._connection.get(url='/certificates/{certificateID}'.format(certificateID=certID))
    def delete(self, certID):
        return self._connection.delete(url='/certificates/{certificateID}'.format(certificateID=certID))
    def getByURL(self, url):
        params = {'URL' : str(url)}
        return self._connection.get(url='/certificates/target', params=params )
    def list(self):
        return self._connection.get(url='/certificates')
    def add(self, payload):
        return self._connection.post(url='/certificates', data=payload)




#  Copyright (c) 2020. Brendan Johnson. All Rights Reserved.

#import connect
#import config

class Contacts:
    def __init__(self, config, connection):
        self._config=config
        self._connection = connection
    ##Contacts
    def list(self):
        return self._connection.get(url='/contacts')
    def create(self, payload):
        return self._connection.post(url='/contacts', data=payload)
    def describe(self, contactID):
        return self._connection.get(url='/contacts/{contactID}'.format(contactID=contactID))
    def modify(self, contactID, payload):
        return self._connection.post(url='/contacts/{contactID}'.format(contactID=contactID), data=payload)
    def delete(self, contactID):
        return self._connection.delete(url='/contacts/{contactID}'.format(contactID=contactID))
    def search(self, payload):
        return self._connection.post(url='/contacts/search', data=payload)





#  Copyright (c) 2020. Brendan Johnson. All Rights Reserved.

#import connect
#import config

class ScheduledTasks:
    def __init__(self, config, connection):
        self._config=config
        self._connection = connection
    ##ScheduledTasks
    def list(self):
        return self._connection.get(url='/scheduledtasks')
    def create(self, payload):
        return self._connection.post(url='/scheduledtasks', data=payload)
    def search(self, payload):
        return self._connection.post(url='/scheduledtasks/search', data=payload)
    def describe(self, scheduledtaskID):
        return self._connection.get(url='/scheduledtasks/{scheduledTaskID}'.format(scheduledTaskID=scheduledtaskID))
    def modify(self, scheduledtaskID, payload):
        return self._connection.post(url='/scheduledtasks/{scheduledTaskID}'.format(scheduledTaskID=scheduledtaskID), data=payload)
    def delete(self, scheduledtaskID):
        return self._connection.delete(url='/scheduledtasks/{scheduledTaskID}'.format(scheduledTaskID=scheduledtaskID))



#  Copyright (c) 2020. Brendan Johnson. All Rights Reserved.

#import connect
#import config

class gcpconnector:
    def __init__(self, config, connection):
        self._config=config
        self._connection = connection

    def createAction(self, id, payload):
        return self._connection.post(url='/gcpconnectors/{gcpConnectorID}/actions'.format(gcpConnectorID=id), data=payload)
    def describeAction(self, id, actionID):
        return self._connection.get(url='/gcpconnectors/{gcpConnectorID}/actions/{actionID}'.format(gcpConnectorID=id, actionID=actionID))
    def list(self):
        return self._connection.get(url='/gcpconnectors')
    def create(self, payload):
        return self._connection.post(url='/gcpconnectors', data=payload)
    def search(self, payload):
        return self._connection.post(url='/gcpconnectors/search', data=payload)
    def describe(self, id):
        return self._connection.get(url='/gcpconnectors/{gcpConnectorID}'.format(gcpConnectorID=id))
    def modify(self, id, payload):
        return self._connection.post(url='/gcpconnectors/{gcpConnectorID}'.format(gcpConnectorID=id), data=payload)
    def delete(self, id):
        return self._connection.delete(url='/gcpconnectors/{gcpConnectorID}'.format(gcpConnectorID=id))








#  Copyright (c) 2020. Brendan Johnson. All Rights Reserved.
#import connect
#import config

class IntrusionPrevention:
    def __init__(self, config, connection):
        self._config=config
        self._connection = connection
    ## Application Types
    def listTypes(self):
        return self._connection.get(url='/applicationtypes')
    def createType(self, payload):
        return self._connection.post(url='/applicationtypes', data=payload)
    def createType(self, applicationTypeID):
        return self._connection.get(url='/applicationtypes/{applicationTypeID}'.format(applicationTypeID=applicationTypeID))
    def modifyType(self, applicationTypeID, payload):
        return self._connection.post(url='/applicationtypes/{applicationTypeID}'.format(applicationTypeID=applicationTypeID), data=payload)
    def deleteType(self, applicationTypeID):
        return self._connection.delete(url='/applicationtypes/{applicationTypeID}'.format(applicationTypeID=applicationTypeID))
    def searchTypes(self, payload):
        return self._connection.post(url='/applicationtypes/search', data=payload)
    ## Rules
    def listRules(self):
        return self._connection.get(url='/intrusionpreventionrules')
    def createRules(self, payload):
        return self._connection.post(url='/intrusionpreventionrules', data=payload)
    def describeRule(self, intrusionPreventionRuleID):
        return self._connection.get(url='/intrusionpreventionrules/{intrusionPreventionRuleID}'.format(intrusionPreventionRuleID=intrusionPreventionRuleID))
    def modifyRule(self, intrusionPreventionRuleID, payload):
        return self._connection.post(url='/intrusionpreventionrules/{intrusionPreventionRuleID}'.format(intrusionPreventionRuleID=intrusionPreventionRuleID), data=payload)
    def deleteRule(self, intrusionPreventionRuleID):
        return self._connection.delete(url='/intrusionpreventionrules/{intrusionPreventionRuleID}'.format(intrusionPreventionRuleID=intrusionPreventionRuleID))
    def searchRules(self, payload):
        return self._connection.post(url='/intrusionpreventionrules/search', data=payload)

